==> haskell-ap-normalize-0.1.0.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ap-normalize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ap-normalize
version:              0.1.0.1
visibility:           public
id:                   ap-normalize-0.1.0.1-LHGgnevVEWgKpZEbVfWUE8
key:                  ap-normalize-0.1.0.1-LHGgnevVEWgKpZEbVfWUE8
license:              MIT
copyright:            Li-yao Xia 2020
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
synopsis:             Self-normalizing applicative expressions
description:
    An applicative functor transformer to normalize expressions using @(\<$>)@,
    @(\<*>)@, and @pure@ into a linear list of actions.
    See "ApNormalize" to get started.

category:             Control
abi:                  2e26d42d2dccb5baf73fa597a214e858
exposed:              True
exposed-modules:      ApNormalize ApNormalize.Aps ApNormalize.DList
import-dirs:          /usr/lib/ghc-8.10.4/site-local/ap-normalize-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/ap-normalize-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/ap-normalize-0.1.0.1
hs-libraries:         HSap-normalize-0.1.0.1-LHGgnevVEWgKpZEbVfWUE8
depends:              base-4.14.1.0
haddock-interfaces:
    /usr/share/doc/haskell-ap-normalize/html/ap-normalize.haddock

haddock-html:         /usr/share/doc/haskell-ap-normalize/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ap-normalize-0.1.0.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ap-normalize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ap-normalize
version:              0.1.0.1
visibility:           public
id:                   ap-normalize-0.1.0.1-JmHVw5TOHGaBHo5q2Wmb1Y
key:                  ap-normalize-0.1.0.1-JmHVw5TOHGaBHo5q2Wmb1Y
license:              MIT
copyright:            Li-yao Xia 2020
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
synopsis:             Self-normalizing applicative expressions
description:
    An applicative functor transformer to normalize expressions using @(\<$>)@,
    @(\<*>)@, and @pure@ into a linear list of actions.
    See "ApNormalize" to get started.

category:             Control
abi:                  6b34a666ec5e982b2fb78def49a3896b
exposed:              True
exposed-modules:      ApNormalize ApNormalize.Aps ApNormalize.DList
import-dirs:          /usr/lib/ghc-8.10.5/site-local/ap-normalize-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/ap-normalize-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/ap-normalize-0.1.0.1
hs-libraries:         HSap-normalize-0.1.0.1-JmHVw5TOHGaBHo5q2Wmb1Y
depends:              base-4.14.2.0
haddock-interfaces:
    /usr/share/doc/haskell-ap-normalize/html/ap-normalize.haddock

haddock-html:         /usr/share/doc/haskell-ap-normalize/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
